| Title: | Interactive Document for Working with Binary Logistic Regression Analysis |
|---|---|
| Description: | An interactive document on the topic of binary logistic regression analysis using 'rmarkdown' and 'shiny' packages. Runtime examples are provided in the package function as well as at <https://analyticmodels.shinyapps.io/BinaryLogisticRegressionModelling/>. |
| Authors: | Kartikeya Bolar |
| Maintainer: | Kartikeya Bolar <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-05-27 07:36:35 UTC |
| Source: | https://github.com/cran/BLRShiny |
BLRShiny() loads interactive user interface built using R 'shiny'.
BLRShiny()BLRShiny()
Start BLRShiny
The interactive user interface is to provide an easy way for binary logistic regression analysis and downloading relevant plot.
Nothing
if(interactive()){ library(rmarkdown) BLRShiny() }if(interactive()){ library(rmarkdown) BLRShiny() }